.. CircLink documentation master file, created by
   sphinx-quickstart on Wed Oct 12 17:12:35 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Tutorial

   basic
   workspace
   config

.. toctree::
   :maxdepth: 2
   :caption: Other Links

   GitHub Repository <https://github.com/tekktrik/circlink>
   PyPI Page <https://pypi.org/project/circlink/>
   Adafruit Discord <https://adafru.it/discord>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
